fetch_google_doc_from_model

Function fetch_google_doc_from_model 

pub async fn fetch_google_doc_from_model(
    url: &str,
    api_token: Option<&str>,
) -> Result<GDocsRenderedResult>
Fetch and render the model data embedded in the Google Docs /edit route.

Errors

Returns an error when the URL is invalid, the fetch fails, or no model chunks are present.