pub fn render_captured_document(
capture: &CapturedDocument,
format: &str,
) -> StringExpand description
Render a parsed Google Docs capture as Markdown, HTML, or text.
pub fn render_captured_document(
capture: &CapturedDocument,
format: &str,
) -> StringRender a parsed Google Docs capture as Markdown, HTML, or text.