pub fn select_capture_method(
capture: &str,
api_token: Option<&str>,
) -> Result<GDocsCaptureMethod>Expand description
Select a Google Docs capture backend from the CLI --capture value.
Errors
Returns an error when capture is neither browser nor api.