pub async fn fetch_html_receipt(
url: &str,
) -> Result<ResponseReceipt, TransportError>Expand description
Fetch an undecoded response through the default reqwest transport.
pub async fn fetch_html_receipt(
url: &str,
) -> Result<ResponseReceipt, TransportError>Fetch an undecoded response through the default reqwest transport.