pub fn verify_markdown_content(
web_content: &WebContent,
markdown_text: &str,
options: &VerifyOptions,
) -> VerifyResultExpand description
Verify that markdown contains the expected web page content.
pub fn verify_markdown_content(
web_content: &WebContent,
markdown_text: &str,
options: &VerifyOptions,
) -> VerifyResultVerify that markdown contains the expected web page content.