select_capture_method

Function select_capture_method 

pub fn select_capture_method(
    capture: &str,
    api_token: Option<&str>,
) -> Result<GDocsCaptureMethod>
Select a Google Docs capture backend from the CLI --capture value.

Errors

Returns an error when capture is neither browser nor api.